Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Error ¶
type Parser ¶
type Parser struct {
// contains filtered or unexported fields
}
func (*Parser) Parse ¶
Parse parses a neugram source file. If non-nil, the returned error is either of type Error or Errors.
type ParserState ¶
type ParserState int
const ( StateUnknown ParserState = iota StateStmt StateStmtPartial StateCmd StateCmdPartial )
type Result ¶
Result is the result of parsing a line of input. One of Stmts or Cmds will be non-nil (but may be empty).
Source Files
¶
- expr_equal.go
- parser.go
- scanner.go
- shell.go
Click to show internal directories.
Click to hide internal directories.